# -*- coding: utf-8 -*-
"""
Copyright (C) 2009-2018 All Rights Reserved. Luiz Fernando Maciel Franca
              www.siginformatica.com.br <luiz@siginformatica.com.br>
                                -------

Copyleft (CC) 2018, Creative Commons
================================================================================
Atribuicao-Nao Comercial-Compartilhada Igual 3.0 Nao Adaptada (CC BY-NC-SA 3.0)
http://creativecommons.org/licenses/by-nc-sa/3.0/deed.pt_BR
================================================================================
"""
from pynfe.xml_sped.base import TagCaracter
from .base import XMLMDFe, NAMESPACE_MDFE
from . import ESQUEMA_ATUAL
import os


DIRNAME = os.path.dirname(__file__)


class Condutor(XMLMDFe):
    """Informacoes do condutor do veiculo."""
    def __init__(self):
        super(Condutor, self).__init__()
        self.xNome = TagCaracter(nome='xNome', tamanho=[2, 50], raiz='//condutor')
        self.cpf = TagCaracter(nome='CPF', tamanho=[11, 11], raiz='//condutor')

    @property
    def xml(self):
        # xml = XMLMDFe.xml.fget()
        xml = ''
        if self.cpf.valor:
            xml += '<condutor>'
            xml += self.xNome.xml
            xml += self.cpf.xml
            xml += '</condutor>'
        return xml

    @xml.setter
    def xml(self, arquivo):
        self.xNome.xml = arquivo
        self.cpf.xml = arquivo


class EvIncCondutorMDFe(XMLMDFe):
    """Leiaute especifico do evento de inclusao de condutor no MDF-e Rodoviario."""
    def __init__(self):
        super(EvIncCondutorMDFe, self).__init__()
        self.descEvento = TagCaracter(
            nome='descEvento', tamanho=[17, 17], raiz='/',
            valor='Inclusao Condutor')
        self.condutor = Condutor()
        self.caminho_esquema = os.path.join(DIRNAME, 'schema/', ESQUEMA_ATUAL + '/')
        self.arquivo_esquema = 'evIncCondutorMDFe_v3.00.xsd'

    @property
    def xml(self):
        xml = '<evIncCondutorMDFe xmlns="%s">' % NAMESPACE_MDFE
        xml += '<descEvento>Inclusao Condutor</descEvento>'
        xml += self.condutor.xml
        xml += '</evIncCondutorMDFe>'
        return xml

    @xml.setter
    def xml(self, arquivo):
        self.descEvento.xml = arquivo
        self.condutor.xml = arquivo

# vim:expandtab:smartindent:tabstop=4:softtabstop=4:shiftwidth=4:
