# -*- coding: utf-8 -*-
"""
Copyright (C) 2009-2018 All Rights Reserved. Luiz Fernando Maciel Franca
              www.siginformatica.com.br <luiz@siginformatica.com.br>
                                -------

Copyleft (CC) 2018, Creative Commons
================================================================================
Atribuicao-Nao Comercial-Compartilhada Igual 3.0 Nao Adaptada (CC BY-NC-SA 3.0)
http://creativecommons.org/licenses/by-nc-sa/3.0/deed.pt_BR
================================================================================
"""
from pynfe.xml_sped.base import TagCaracter, TagInteiro
from .base import XMLMDFe, NAMESPACE_MDFE
from . import ESQUEMA_ATUAL
import os


DIRNAME = os.path.dirname(__file__)


class InfTermCarreg(XMLMDFe):
    """Grupo de informacoes dos terminais de carregamento"""
    def __init__(self):
        super(InfTermCarreg, self).__init__()
        self.cTermCarreg = TagCaracter(
            nome='cTermCarreg', tamanho=[1, 8], raiz='//aquav/infTermCarreg')
        self.xTermCarreg = TagCaracter(
            nome='xTermCarreg', tamanho=[1, 60], raiz='//aquav/infTermCarreg')

    @property
    def xml(self):
        xml = '<infTermCarreg>'
        xml += self.cTermCarreg.xml
        xml += self.xTermCarreg.xml
        xml += '</infTermCarreg>'
        return xml

    @xml.setter
    def xml(self, arquivo):
        self.cTermCarreg.xml = arquivo
        self.xTermCarreg.xml = arquivo


class InfTermDescarreg(XMLMDFe):
    """Grupo de informacoes dos terminais de descarregamento"""
    def __init__(self):
        super(InfTermDescarreg, self).__init__()
        self.cTermDescarreg = TagCaracter(
            nome='cTermDescarreg', tamanho=[1, 8], raiz='//aquav/infTermDescarreg')
        self.xTermDescarreg = TagCaracter(
            nome='xTermDescarreg', tamanho=[1, 60], raiz='//aquav/infTermDescarreg')

    @property
    def xml(self):
        xml = '<infTermDescarreg>'
        xml += self.cTermDescarreg.xml
        xml += self.xTermDescarreg.xml
        xml += '</infTermCarreg>'
        return xml

    @xml.setter
    def xml(self, arquivo):
        self.cTermDescarreg.xml = arquivo
        self.xTermDescarreg.xml = arquivo


class InfEmbComb(XMLMDFe):
    """Grupo de informacoes das embarcacoes do comboio"""
    def __init__(self):
        super(InfEmbComb, self).__init__()
        self.cEmbComb = TagCaracter(nome='cEmbComb', tamanho=[1, 10], raiz='//aquav/infEmbComb')
        self.xBalsa = TagCaracter(nome='xBalsa', tamanho=[1, 60], raiz='//aquav/infEmbComb')

    @property
    def xml(self):
        xml = '<infEmbComb>'
        xml += self.cEmbComb.xml
        xml += self.xBalsa.xml
        xml += '</infEmbComb>'
        return xml

    @xml.setter
    def xml(self, arquivo):
        self.cEmbComb.xml = arquivo
        self.xBalsa.xml = arquivo


class InfUnidCargaVazia(XMLMDFe):
    """Informacoes das unidades de cargas vazias"""
    def __init__(self):
        super(InfUnidCargaVazia, self).__init__()
        self.idUnidCargaVazia = TagCaracter(
            nome='idUnidCargaVazia', tamanho=[1, 20], raiz='//aquav/infUnidCargaVazia')
        self.tpUnidCargaVazia = TagInteiro(
            nome='tpUnidCargaVazia', tamanho=[1, 1, 1], raiz='//aquav/infUnidCargaVazia')

    @property
    def xml(self):
        xml = '<infUnidCargaVazia>'
        xml += self.idUnidCargaVazia.xml
        xml += self.tpUnidCargaVazia.xml
        xml += '</infUnidCargaVazia>'
        return xml

    @xml.setter
    def xml(self, arquivo):
        self.idUnidCargaVazia.xml = arquivo
        self.tpUnidCargaVazia.xml = arquivo


class InfUnidTranspVazia(XMLMDFe):
    """Informacoes das unidades de cargas vazias"""
    def __init__(self):
        super(InfUnidTranspVazia, self).__init__()
        self.idUnidTranspVazia = TagCaracter(
            nome='idUnidTranspVazia', tamanho=[1, 20], raiz='//aquav/infUnidTranspVazia')
        self.tpUnidTranspVazia = TagInteiro(
            nome='tpUnidTranspVazia', tamanho=[1, 1, 1], raiz='//aquav/infUnidTranspVazia')

    @property
    def xml(self):
        xml = '<infUnidTranspVazia>'
        xml += self.idUnidTranspVazia.xml
        xml += self.tpUnidTranspVazia.xml
        xml += '</infUnidTranspVazia>'
        return xml

    @xml.setter
    def xml(self, arquivo):
        self.idUnidTranspVazia.xml = arquivo
        self.tpUnidTranspVazia.xml = arquivo


class ModalAquav(XMLMDFe):
    """Informacoes do Modal Aereo"""
    def __init__(self):
        super(ModalAquav, self).__init__()
        self.caminho_esquema = os.path.join(DIRNAME, 'schema/', ESQUEMA_ATUAL + '/')
        self.arquivo_esquema = 'mdfeModalAquaviario_v3.00.xsd'
        self.irin = TagCaracter(nome='irin', tamanho=[1, 10], raiz='//aquav')
        self.tpEmb = TagInteiro(nome='tpEmb', tamanho=[2, 2, 1], raiz='//aquav')
        self.cEmbar = TagCaracter(nome='cEmbar', tamanho=[1, 10], raiz='//aquav')
        self.xEmbar = TagCaracter(nome='xEmbar', tamanho=[1, 60], raiz='//aquav')
        self.nViag = TagInteiro(nome='nViag', tamanho=[1, 10, 1], raiz='//aquav')
        self.cPrtEmb = TagCaracter(nome='cPrtEmb', tamanho=[1, 5], raiz='//aquav')
        self.cPrtDest = TagCaracter(nome='cPrtDest', tamanho=[1, 5], raiz='//aquav')
        self.prtTrans = TagCaracter(
            nome='prtTrans', tamanho=[1, 60], raiz='//aquav', obrigatorio=False)
        self.tpNav = TagInteiro(
            nome='tpNav', tamanho=[1, 1, 1], raiz='//aquav', obrigatorio=False)
        self.infTermCarreg = []  # Nao obrigatorio - Maximo 5
        self.infTermDescarreg = []  # Nao obrigatorio - Maximo 5
        self.infEmbComb = []  # Nao obrigatorio - Maximo 30
        self.infUnidCargaVazia = []  # Nao obrigatorio
        self.infUnidTranspVazia = []  # Nao obrigatorio

    @property
    def xml(self):
        xml = '<aquav xmlns="%s">' % NAMESPACE_MDFE
        xml += self.irin.xml
        xml += self.tpEmb.xml
        xml += self.cEmbar.xml
        xml += self.xEmbar.xml
        xml += self.nViag.xml
        xml += self.cPrtEmb.xml
        xml += self.cPrtDest.xml
        xml += self.tpNav.xml
        for itc in self.infTermCarreg[:5]:  # Nao obrigatorio - De 0 a 5 ocorrencias
            xml += itc.xml
        for itd in self.infTermDescarreg[:5]:  # Nao obrigatorio - De 0 a 5 ocorrencias
            xml += itd.xml
        for iec in self.infEmbComb[:30]:  # Nao obrigatorio - De 0 a 30 ocorrencias
            xml += iec.xml
        for iuc in self.infUnidCargaVazia:
            xml += iuc.xml
        for iut in self.infUnidTranspVazia:
            xml += iut.xml
        xml += '</aquav>'
        return xml

    @xml.setter
    def xml(self, arquivo):
        self.irin.xml = arquivo
        self.tpEmb.xml = arquivo
        self.cEmbar.xml = arquivo
        self.xEmbar.xml = arquivo
        self.nViag.xml = arquivo
        self.cPrtEmb.xml = arquivo
        self.cPrtDest.xml = arquivo
        self.tpNav.xml = arquivo
        self.infTermCarreg = self.le_grupo('//aquav/infTermCarreg', InfTermCarreg)
        self.infTermDescarreg = self.le_grupo('//aquav/infTermDescarreg', InfTermDescarreg)
        self.infEmbComb = self.le_grupo('//aquav/infEmbComb', InfEmbComb)
        self.infUnidCargaVazia = self.le_grupo('//aquav/infUnidCargaVazia', InfUnidCargaVazia)
        self.infUnidTranspVazia = self.le_grupo('//aquav/infUnidTranspVazia', InfUnidTranspVazia)


# vim:expandtab:smartindent:tabstop=4:softtabstop=4:shiftwidth=4:
