# -*- coding: utf-8 -*-
"""
Copyright (C) 2009-2018 All Rights Reserved. Luiz Fernando Maciel Franca
              www.siginformatica.com.br <luiz@siginformatica.com.br>
                                -------

Copyleft (CC) 2018, Creative Commons
================================================================================
Atribuicao-Nao Comercial-Compartilhada Igual 3.0 Nao Adaptada (CC BY-NC-SA 3.0)
http://creativecommons.org/licenses/by-nc-sa/3.0/deed.pt_BR
================================================================================
"""
from pynfe.xml_sped.base import TagCaracter, TagInteiro, TagDecimal
from .base import XMLMDFe, NAMESPACE_MDFE
from . import ESQUEMA_ATUAL
import os


DIRNAME = os.path.dirname(__file__)


class InfCIOT(XMLMDFe):
    """Dados do CIOT - Codigo Identificador da Operacao de Transporte"""
    def __init__(self):
        super(InfCIOT, self).__init__()
        self.ciot = TagInteiro(nome='CIOT', tamanho=[12, 12, 1], raiz='//infCIOT')
        self.cpf = TagCaracter(nome='CPF', tamanho=[11, 11, 1], raiz='//infCIOT')
        self.cnpj = TagCaracter(nome='CNPJ', tamanho=[14, 14, 1], raiz='//infCIOT')

    @property
    def xml(self):
        xml = '<infCIOT>'
        xml += self.ciot.xml
        xml += self.cpf.xml if self.cpf.valor else self.cnpj.xml
        xml += '</infCIOT>'
        return xml

    @xml.setter
    def xml(self, arquivo):
        self.ciot.xml = arquivo
        self.cpf.xml = arquivo
        self.cnpj.xml = arquivo


class Disp(XMLMDFe):
    """Grupo de informacoes dos dispositivos do Vale Pedagio"""
    def __init__(self):
        super(Disp, self).__init__()
        self.cnpjForn = TagCaracter(nome='CNPJForn', tamanho=[14, 14, 1], raiz='//disp')
        self.cnpjPg = TagCaracter(nome='CNPJPg', tamanho=[14, 14, 1], raiz='//disp')
        self.cpfPg = TagCaracter(nome='CPFPg', tamanho=[11, 11, 1], raiz='//disp')
        self.nCompra = TagCaracter(nome='nCompra', tamanho=[1, 20], raiz='//disp')
        self.vValePed = TagDecimal(
            nome='vValePed', tamanho=[1, 15, 1], decimais=[0, 2, 2], raiz='//disp')

    @property
    def xml(self):
        xml = '<disp>'
        xml += self.cnpjForn.xml
        xml += self.cnpjPg.xml if self.cnpjPg.valor else self.cpfPg.xml
        xml += self.nCompra.xml
        xml += self.vValePed.xml
        xml += '</disp>'
        return xml

    @xml.setter
    def xml(self, arquivo):
        self.cnpjForn.xml = arquivo
        self.cnpjPg.xml = arquivo
        self.cpfPg.xml = arquivo
        self.nCompra.xml = arquivo
        self.vValePed.xml = arquivo


class ValePed(XMLMDFe):
    """Informacoes do Vale Pedagio"""
    def __init__(self):
        super(ValePed, self).__init__()
        self.disp = []

    @property
    def xml(self):
        # xml = XMLMDFe.xml.fget()
        xml = ''
        if self.disp:  # Nao obrigatorio
            xml += '<valePed>'
            for d in self.disp:
                xml += d.xml
            xml += '</valePed>'
        return xml

    @xml.setter
    def xml(self, arquivo):
        if self._le_xml(arquivo):
            self.disp = self.le_grupo('//valePed/disp', Disp)


class InfContratante(XMLMDFe):
    """Grupo de informacoes dos contratantes de servicos de transporte"""
    def __init__(self):
        super(InfContratante, self).__init__()
        self.cpf = TagCaracter(
            nome='CPF', tamanho=[11, 11, 1], raiz='//infContratante')
        self.cnpj = TagCaracter(
            nome='CNPJ', tamanho=[14, 14, 1], raiz='//infContratante')

    @property
    def xml(self):
        xml = '<infContratante>'
        xml += self.cpf.xml if self.cpf.valor else self.cnpj.valor
        xml += '</infContratante>'
        return xml

    @xml.setter
    def xml(self, arquivo):
        self.cpf.xml = arquivo
        self.cnpj.xml = arquivo


class InfANTT(XMLMDFe):
    """Informacoes para Agencia Reguladora"""
    def __init__(self):
        super(InfANTT, self).__init__()
        self.rntrc = TagCaracter(
            nome='RNTRC', tamanho=[8, 8, 1], raiz='//infANTT', obrigatorio=False)
        self.infCIOT = []  # Nao obrigatorio
        self.valePed = ValePed()  # Nao obrigatorio
        self.infContratante = []  # Nao obrigatorio

    @property
    def xml(self):
        # xml = XMLMDFe.xml.fget()
        xml = ''
        if self.rntrc.valor:  # Nao obrigatorio
            xml = '<infANTT>'
            xml += self.rntrc.xml
            for ic in self.infCIOT:
                xml += ic.xml
            xml += self.valePed.xml
            for ic in self.infContratante:
                xml += ic.xml
            xml += '</infANTT>'
        return xml

    @xml.setter
    def xml(self, arquivo):
        if self._le_xml(arquivo):
            self.rntrc.xml = arquivo
            self.infCIOT = self.le_grupo('//infANTT/infCIOT', InfCIOT)
            self.valePed.xml = arquivo
            self.infContratante = self.le_grupo('//infANTT/infContratante', InfContratante)


class Prop(XMLMDFe):
    """Proprietario do veiculo - Somente quando o veiculo nao pertencer a empresa emitente"""
    def __init__(self):
        super(Prop, self).__init__()
        self.cpf = TagCaracter(nome='CPF', tamanho=[11, 11, 1], raiz='//prop')
        self.cnpj = TagCaracter(nome='CNPJ', tamanho=[14, 14, 1], raiz='//prop')
        self.rntrc = TagCaracter(nome='RNTRC', tamanho=[8, 8, 1], raiz='//prop')
        self.xNome = TagCaracter(nome='xNome', tamanho=[2, 60], raiz='//prop')
        self.ie = TagCaracter(nome='IE', tamanho=[1, 14], raiz='//prop')
        self.uf = TagCaracter(nome='UF', tamanho=[2, 2], raiz='//prop')
        self.tpProp = TagInteiro(nome='tpProp', tamanho=[1, 1, 1], raiz='//prop')

    @property
    def xml(self):
        # xml = XMLMDFe.xml.fget()
        xml = ''
        if self.cpf.valor or self.cnpj.valor:  # Nao obrigatorio
            xml = '<prop>'
            xml += self.cpf.xml if self.cpf.valor else self.cnpj.xml
            xml += self.rntrc.xml
            xml += self.xNome.xml
            if self.ie.valor or self.uf.valor:  # Se IE ou UF, ambas devem ser informadas
                xml += self.ie.xml
                xml += self.uf.xml
            xml += self.tpProp.xml
            xml += '</prop>'
        return xml

    @xml.setter
    def xml(self, arquivo):
        self.cpf.xml = arquivo
        self.cnpj.xml = arquivo
        self.rntrc.xml = arquivo
        self.xNome.xml = arquivo
        self.ie.xml = arquivo
        self.uf.xml = arquivo
        self.tpProp.xml = arquivo


class Condutor(XMLMDFe):
    """Informacoes dos condutores do veiculo"""
    def __init__(self):
        super(Condutor, self).__init__()
        self.xNome = TagCaracter(nome='xNome', tamanho=[2, 60], raiz='//condutor')
        self.cpf = TagCaracter(nome='CPF', tamanho=[11, 11, 1], raiz='//condutor')

    @property
    def xml(self):
        xml = '<condutor>'
        xml += self.xNome.xml
        xml += self.cpf.xml
        xml += '</condutor>'
        return xml

    @xml.setter
    def xml(self, arquivo):
        if self._le_xml(arquivo):
            self.xNome.xml = arquivo
            self.cpf.xml = arquivo


class PropReboque(Prop):
    """Proprietario do veiculo - Somente quando o veiculo nao pertencer a empresa emitente"""
    def __init__(self):
        super(PropReboque, self).__init__()


class VeicReboque(XMLMDFe):
    """Dados dos reboques"""
    def __init__(self):
        super(VeicReboque, self).__init__()
        self.cInt = TagCaracter(
            nome='cInt', tamanho=[1, 10, 1], raiz='//veicReboque', obrigatorio=False)
        self.placa = TagCaracter(nome='placa', tamanho=[7, 7], raiz='//veicReboque')
        self.renavan = TagCaracter(
            nome='RENAVAN', tamanho=[9, 11], raiz='//veicReboque', obrigatorio=False)
        self.tara = TagInteiro(nome='tara', tamanho=[1, 6, 1], raiz='//veicReboque')
        self.capKg = TagInteiro(nome='capKG', tamanho=[1, 6, 1], raiz='//veicReboque')
        self.capM3 = TagInteiro(
            nome='capM3', tamanho=[1, 3, 1], raiz='//veicReboque', obrigatorio=False)
        self.prop = PropReboque()  # Nao obrigatorio
        self.tpCar = TagCaracter(nome='tpCar', tamanho=[2, 2, 1], raiz='//veicReboque')
        self.uf = TagCaracter(nome='UF', tamanho=[2, 2], raiz='//veicReboque')

    @property
    def xml(self):
        xml = '<veicReboque>'
        xml += self.cInt.xml
        xml += self.placa.xml
        xml += self.renavan.xml
        xml += self.tara.xml
        xml += self.capKg.xml
        xml += self.capM3.xml
        xml += self.prop.xml
        xml += self.tpCar.xml
        xml += self.uf.xml
        xml += '</veicReboque>'
        return xml

    @xml.setter
    def xml(self, arquivo):
        self.cInt.xml = arquivo
        self.placa.xml = arquivo
        self.renavan.xml = arquivo
        self.tara.xml = arquivo
        self.capKg.xml = arquivo
        self.capM3.xml = arquivo
        self.prop.xml = arquivo
        self.tpCar.xml = arquivo
        self.uf.xml = arquivo


class LacRodo(XMLMDFe):
    """Lacres"""
    def __init__(self):
        super(LacRodo, self).__init__()
        self.nLacre = TagCaracter(
            nome='nLacre', tamanho=[1, 20], raiz='//lacRodo', obrigatorio=False)

    @property
    def xml(self):
        # xml = XMLMDFe.xml.fget()
        xml = ''
        if self.nLacre.valor:
            xml += '<lacRodo>'
            xml += self.nLacre.xml
            xml += '</lacRodo>'
        return xml

    @xml.setter
    def xml(self, arquivo):
        self.nLacre.xml = arquivo


class VeicTracao(XMLMDFe):
    """Dados do veiculo com a tracao"""
    def __init__(self):
        super(VeicTracao, self).__init__()
        self.cInt = TagCaracter(
            nome='cInt', tamanho=[1, 10, 1], raiz='//veicTracao', obrigatorio=False)
        self.placa = TagCaracter(nome='placa', tamanho=[7, 7], raiz='//veicTracao')
        self.renavan = TagCaracter(
            nome='RENAVAN', tamanho=[9, 11], raiz='//veicTracao', obrigatorio=False)
        self.tara = TagInteiro(nome='tara', tamanho=[1, 6, 1], raiz='//veicTracao')
        self.capKg = TagInteiro(
            nome='capKG', tamanho=[1, 6, 1], raiz='//veicTracao', obrigatorio=False)
        self.capM3 = TagInteiro(
            nome='capM3', tamanho=[1, 3, 1], raiz='//veicTracao', obrigatorio=False)
        self.prop = Prop()  # Nao obrigatorio
        self.condutor = []  # Obrigatorio - De 1 a 10
        self.tpRod = TagCaracter(nome='tpRod', tamanho=[2, 2, 1], raiz='//veicTracao')
        self.tpCar = TagCaracter(nome='tpCar', tamanho=[2, 2, 1], raiz='//veicTracao')
        self.uf = TagCaracter(nome='UF', tamanho=[2, 2, 2], raiz='//veicTracao')

    @property
    def xml(self):
        xml = '<veicTracao>'
        xml += self.cInt.xml
        xml += self.placa.xml
        xml += self.renavan.xml
        xml += self.tara.xml
        xml += self.capKg.xml
        xml += self.capM3.xml
        xml += self.prop.xml
        for c in self.condutor[:10] or [Condutor()]:  # De 1 a 10 ocorencias
            xml += c.xml
        xml += self.tpRod.xml
        xml += self.tpCar.xml
        xml += self.uf.xml
        xml += '</veicTracao>'
        return xml

    @xml.setter
    def xml(self, arquivo):
        if self._le_xml(arquivo):
            self.cInt.xml = arquivo
            self.placa.xml = arquivo
            self.renavan.xml = arquivo
            self.tara.xml = arquivo
            self.capKg.xml = arquivo
            self.capM3.xml = arquivo
            self.prop.xml = arquivo
            self.condutor = self.le_grupo('//veicTracao/condutor', Condutor)
            self.tpRod.xml = arquivo
            self.tpCar.xml = arquivo
            self.uf.xml = arquivo


class ModalRodo(XMLMDFe):
    """Informacoes do Modal Rodoviario"""
    def __init__(self):
        super(ModalRodo, self).__init__()
        self.infANTT = InfANTT()  # Nao obrigatorio
        self.veicTracao = VeicTracao()
        self.veicReboque = []  # Nao obrigatorio - De 0 a 3 ocorrencias
        self.codAgPorto = TagCaracter(
            nome='codAgPort', tamanho=[1, 16], raiz='//rodo', obrigatorio=False)
        self.lacRodo = []  # Nao obrigatorio
        self.caminho_esquema = os.path.join(DIRNAME, 'schema/', ESQUEMA_ATUAL + '/')
        self.arquivo_esquema = 'mdfeModalRodoviario_v3.00.xsd'

    @property
    def xml(self):
        xml = '<rodo xmlns="%s">' % NAMESPACE_MDFE
        xml += self.infANTT.xml
        xml += self.veicTracao.xml
        for vr in self.veicReboque[:3]:  # Nao obrigatorio - De 0 a 3 ocorrencias
            xml += vr.xml
        xml += self.codAgPorto.xml
        for lr in self.lacRodo:  # Nao obrigatorio
            xml += lr.xml
        xml += '</rodo>'
        return xml

    @xml.setter
    def xml(self, arquivo):
        if self._le_xml(arquivo):
            self.infANTT.xml = arquivo
            self.veicTracao.xml = arquivo
            self.veicReboque = self.le_grupo('//rodo', VeicReboque)
            self.codAgPorto.xml = arquivo
            self.lacRodo = self.le_grupo('//rodo', LacRodo)

# vim:expandtab:smartindent:tabstop=4:softtabstop=4:shiftwidth=4:
