# -*- coding: utf-8 -*-
"""
Copyright (C) 2009-2018 All Rights Reserved. Luiz Fernando Maciel Franca
              www.siginformatica.com.br <luiz@siginformatica.com.br>
                                -------

Copyleft (CC) 2018, Creative Commons
================================================================================
Atribuicao-Nao Comercial-Compartilhada Igual 3.0 Nao Adaptada (CC BY-NC-SA 3.0)
http://creativecommons.org/licenses/by-nc-sa/3.0/deed.pt_BR
================================================================================
"""
from pynfe.xml_sped.base import TagDecimal, TagInteiro, TagCaracter
from .base import XMLMDFe, NAMESPACE_MDFE
from . import ESQUEMA_ATUAL
import os


DIRNAME = os.path.dirname(__file__)


class InfMDFe(XMLMDFe):
    """Grupo com relação de MDF-e nao encerrados."""
    def __init__(self):
        super(InfMDFe, self).__init__()
        self.chMDFe = TagCaracter(nome='chMDFe', tamanho=[44, 44], raiz='//infMDFe')
        self.nProt = TagCaracter(nome='nProt', tamanho=[15, 15], raiz='//infMDFe')

    @property
    def xml(self):
        xml = '<infMDFe>'
        xml += self.chMDFe.xml
        xml += self.nProt.xml
        xml += '</infMDFe>'
        return xml

    @xml.setter
    def xml(self, arquivo):
        self.chMDFe.xml = arquivo
        self.nProt.xml = arquivo


class RetConsMDFeNaoEnc(XMLMDFe):
    """Leiaute da retorno da consulta MDF-e nao encerrados."""
    def __init__(self):
        super(RetConsMDFeNaoEnc, self).__init__()
        self.versao = TagDecimal(
            nome='retConsMDFeNaoEnc', tamanho=[1, 4, 1], decimais=[0, 2, 2], propriedade='versao',
            raiz='/', namespace=NAMESPACE_MDFE, valor='3.00')
        self.tpAmb = TagInteiro(nome='tpAmb', tamanho=[1, 1], raiz='//retConsMDFeNaoEnc')
        self.verAplic = TagCaracter(nome='verAplic', tamanho=[1, 20], raiz='//retConsMDFeNaoEnc')
        self.cStat = TagCaracter(nome='cStat', tamanho=[3, 3], raiz='//retConsMDFeNaoEnc')
        self.xMotivo = TagCaracter(nome='xMotivo', tamanho=[1, 255], raiz='//retConsMDFeNaoEnc')
        self.cUF = TagInteiro(nome='cUF', tamanho=[2, 2], raiz='//retConsMDFeNaoEnc')
        self.infMDFe = []
        self.caminho_esquema = os.path.join(DIRNAME, 'schema/', ESQUEMA_ATUAL + '/')
        self.arquivo_esquema = 'retConsMDFeNaoEnc_v3.00.xsd'

    @property
    def xml(self):
        xml = '<retConsMDFeNaoEnc xmlns="%s" versao="%s">' % (NAMESPACE_MDFE, self.versao.valor)
        xml += self.tpAmb.xml
        xml += self.verAplic.xml
        xml += self.cStat.xml
        xml += self.xMotivo.xml
        xml += self.cUF.xml
        for i in self.infMDFe:
            xml += i.xml
        xml += '</retConsMDFeNaoEnc>'
        return xml

    @xml.setter
    def xml(self, arquivo):
        if self._le_xml(arquivo):
            self.versao.xml = arquivo
            self.tpAmb.xml = arquivo
            self.verAplic.xml = arquivo
            self.cStat.xml = arquivo
            self.xMotivo.xml = arquivo
            self.cUF.xml = arquivo
            self.infMDFe = self.le_grupo('//infMDFe', InfMDFe)

# vim:expandtab:smartindent:tabstop=4:softtabstop=4:shiftwidth=4:
