# -*- coding: utf-8 -*-
"""
Copyright (C) 2009-2018 All Rights Reserved. Luiz Fernando Maciel Franca
              www.siginformatica.com.br <luiz@siginformatica.com.br>
                                -------

Copyleft (CC) 2018, Creative Commons
================================================================================
Atribuicao-Nao Comercial-Compartilhada Igual 3.0 Nao Adaptada (CC BY-NC-SA 3.0)
http://creativecommons.org/licenses/by-nc-sa/3.0/deed.pt_BR
================================================================================
"""
from pynfe.xml_sped.base import TagCaracter, TagInteiro, TagDecimal, ABERTURA
from .procEventoMDFe import ProcEventoMDFe
from .base import XMLMDFe, NAMESPACE_MDFE
from .retConsReciMDFe import ProtMDFe
from .import ESQUEMA_ATUAL
import os


DIRNAME = os.path.dirname(__file__)


class RetConsSitMDFe(XMLMDFe):
    """Mensagem de consulta da situacao atual do MDF-e."""
    def __init__(self):
        super(RetConsSitMDFe, self).__init__()
        self.versao = TagDecimal(
            nome='retConsSitMDFe', tamanho=[1, 4, 1], decimais=[0, 2, 2], propriedade='versao',
            raiz='/', namespace=NAMESPACE_MDFE, valor='3.00')
        self.tpAmb = TagInteiro(nome='tpAmb', tamanho=[1, 1], raiz='//retConsSitMDFe')
        self.verAplic = TagCaracter(nome='verAplic', tamanho=[1, 20], raiz='//retConsSitMDFe')
        self.cStat = TagCaracter(nome='cStat', tamanho=[3, 3], raiz='//retConsSitMDFe')
        self.xMotivo = TagCaracter(nome='xMotivo', tamanho=[1, 255], raiz='//retConsSitMDFe')
        self.protMDFe = ProtMDFe()
        self.procEventoMDFe = []
        self.caminho_esquema = os.path.join(DIRNAME, 'schema/', ESQUEMA_ATUAL + '/')
        self.arquivo_esquema = 'retConsSitMDFe_v3.00.xsd'

    @property
    def xml(self):
        xml = '%s<retConsSitMDFe xmlns="%s" versao="%s">' % (ABERTURA, NAMESPACE_MDFE, self.versao.valor)
        xml += self.tpAmb.xml
        xml += self.verAplic.xml
        xml += self.cStat.xml
        xml += self.xMotivo.xml
        xml += self.protMDFe.xml
        for p in self.procEventoMDFe:
            xml += p.xml
        xml += '</retConsSitMDFe>'
        return xml

    @xml.setter
    def xml(self, arquivo):
        if self._le_xml(arquivo):
            self.versao.xml = arquivo
            self.tpAmb.xml = arquivo
            self.verAplic.xml = arquivo
            self.cStat.xml = arquivo
            self.xMotivo.xml = arquivo
            self.protMDFe.xml = arquivo
            self.procEventoMDFe = self.le_grupo('//procEventoMDFe', ProcEventoMDFe)

# vim:expandtab:smartindent:tabstop=4:softtabstop=4:shiftwidth=4:
