# -*- coding: utf-8 -*-
"""
Copyright (C) 2009-2018 All Rights Reserved. Luiz Fernando Maciel Franca
              www.siginformatica.com.br <luiz@siginformatica.com.br>
                                -------

Copyleft (CC) 2018, Creative Commons
================================================================================
Atribuicao-Nao Comercial-Compartilhada Igual 3.0 Nao Adaptada (CC BY-NC-SA 3.0)
http://creativecommons.org/licenses/by-nc-sa/3.0/deed.pt_BR
================================================================================
"""
from pynfe.xml_sped.base import TagCaracter, TagInteiro, TagDecimal, TagDataHoraUTC, TagDataHora
from .base import XMLMDFe, NAMESPACE_MDFE
from . import ESQUEMA_ATUAL
import os


DIRNAME = os.path.dirname(__file__)


class RetConsStatServMDFe(XMLMDFe):
    """Mensagem de retorno da consulta do status do servico de autorizacao do MDF-e."""
    def __init__(self):
        super(RetConsStatServMDFe, self).__init__()
        self.versao = TagDecimal(
            nome='retConsStatServMDFe', tamanho=[1, 4, 1], decimais=[0, 2, 2],
            propriedade='versao', raiz='/', namespace=NAMESPACE_MDFE, valor='3.00')
        self.tpAmb = TagInteiro(nome='tpAmb', tamanho=[1, 1], raiz='//retConsStatServMDFe')
        self.verAplic = TagCaracter(
            nome='verAplic', tamanho=[1, 20], raiz='//retConsStatServMDFe')
        self.cStat = TagCaracter(nome='cStat', tamanho=[3, 3], raiz='//retConsStatServMDFe')
        self.xMotivo = TagCaracter(nome='xMotivo', tamanho=[1, 255], raiz='//retConsStatServMDFe')
        self.cUF = TagInteiro(nome='cUF', tamanho=[2, 2], raiz='//retConsStatServMDFe')
        self.dhRecbto = TagDataHoraUTC(nome='dhRecbto', raiz='//retConsStatServMDFe')
        self.tMed = TagInteiro(nome='tMed', tamanho=[1, 4], raiz='//retConsStatServMDFe')
        self.dhRetorno = TagDataHora(
            nome='dhRetorno', raiz='//retConsStatServMDFe', obrigatorio=False)
        self.xObs = TagCaracter(nome='xObs', tamanho=[1, 255], raiz='//retConsStatServMDFe')
        self.caminho_esquema = os.path.join(DIRNAME, 'schema/', ESQUEMA_ATUAL + '/')
        self.arquivo_esquema = 'retConsStatServMDFe_v3.00.xsd'

    @property
    def xml(self):
        xml = '<retConsStatServMDFe xmlns="%s" versao="%s">' % (NAMESPACE_MDFE, self.versao.valor)
        xml += self.tpAmb.xml
        xml += self.verAplic.xml
        xml += self.cStat.xml
        xml += self.xMotivo.xml
        xml += self.cUF.xml
        xml += self.dhRecbto.xml
        xml += self.tMed.xml
        xml += self.dhRetorno.xml
        xml += self.xObs.xml
        xml += '</retConsStatServMDFe>'
        return xml

    @xml.setter
    def xml(self, arquivo):
        self.versao.xml = arquivo
        self.tpAmb.xml = arquivo
        self.verAplic.xml = arquivo
        self.cStat.xml = arquivo
        self.xMotivo.xml = arquivo
        self.cUF.xml = arquivo
        self.dhRecbto.xml = arquivo
        self.tMed.xml = arquivo
        self.dhRetorno.xml = arquivo
        self.xObs.xml = arquivo

# vim:expandtab:smartindent:tabstop=4:softtabstop=4:shiftwidth=4:
