# -*- coding: utf-8 -*-
"""
Copyright (C) 2009-2018 All Rights Reserved. Luiz Fernando Maciel Franca
              www.siginformatica.com.br <luiz@siginformatica.com.br>
                                -------

Copyleft (CC) 2018, Creative Commons
================================================================================
Atribuicao-Nao Comercial-Compartilhada Igual 3.0 Nao Adaptada (CC BY-NC-SA 3.0)
http://creativecommons.org/licenses/by-nc-sa/3.0/deed.pt_BR
================================================================================
"""
from pynfe.xml_sped.base import TagCaracter, TagInteiro, TagDecimal, TagDataHoraUTC
from pynfe.xml_sped.assinatura import Signature
from pynfe.xml_sped.base import ABERTURA
from .base import XMLMDFe, NAMESPACE_MDFE
from . import ESQUEMA_ATUAL
import os


DIRNAME = os.path.dirname(__file__)


class InfEvento(XMLMDFe):
    """Grupo de informacoes do registro do evento."""
    def __init__(self):
        super(InfEvento, self).__init__()
        self.Id = TagCaracter(nome='infEvento', tamnho=[48, 48], propriedade='Id', raiz='/')
        self.tpAmb = TagInteiro(nome='tpAmb', tamanho=[1, 1], raiz='//infEvento')
        self.verAplic = TagCaracter(nome='verAplic', tamanho=[1, 20], raiz='//infEvento')
        self.cOrgao = TagInteiro(nome='cOrgao', tamanho=[2, 2], raiz='//infEvento')
        self.cStat = TagCaracter(nome='cStat', tamanho=[3, 3], raiz='//infEvento')
        self.xMotivo = TagCaracter(nome='xMotivo', tamanho=[1, 255], raiz='//infEvento')
        self.chMDFe = TagInteiro(
            nome='chMDFe', tamanho=[44, 44], raiz='//infEvento', obrigatorio=False)
        self.tpEvento = TagCaracter(nome='tpEvento', tamanho=[6, 6, 6], raiz='//infEvento', obrigatorio=False)
        self.xEvento = TagCaracter(
            nome='xEvento', tamanho=[5, 60], raiz='//infEvento', obrigatorio=False)
        self.nSeqEvento = TagInteiro(
            nome='nSeqEvento', tamanho=[1, 2], raiz='//infEvento', obrigatorio=False)
        self.dhRegEvento = TagDataHoraUTC(
            nome='dhRegEvento', raiz='//infEvento', obrigatorio=False)
        self.nProt = TagCaracter(
            nome='nProt', tamanho=[15, 15], raiz='//infEvento', obrigatorio=False)
        self.signature = Signature()

    @property
    def xml(self):
        xml = '<infEvento Id="%s">' % self.Id.valor
        xml += self.tpAmb.xml
        xml += self.verAplic.xml
        xml += self.cOrgao.xml
        xml += self.cStat.xml
        xml += self.xMotivo.xml
        xml += self.chMDFe.xml
        xml += self.tpEvento.xml
        xml += self.xEvento.xml
        xml += self.nSeqEvento.xml
        xml += self.dhRegEvento.xml
        xml += self.nProt.xml
        xml += '</infEvento>'
        return xml

    @xml.setter
    def xml(self, arquivo):
        self.Id.xml = arquivo
        self.tpAmb.xml = arquivo
        self.verAplic.xml = arquivo
        self.cOrgao.xml = arquivo
        self.cStat.xml = arquivo
        self.xMotivo.xml = arquivo
        self.chMDFe.xml = arquivo
        self.tpEvento.xml = arquivo
        self.xEvento.xml = arquivo
        self.nSeqEvento.xml = arquivo
        self.dhRegEvento.xml = arquivo
        self.nProt.xml = arquivo


class RetEventoMDFe(XMLMDFe):
    """Mensagem de retorno do resultado da solicitacao de registro de evento do MDF-e."""
    def __init__(self):
        super(RetEventoMDFe, self).__init__()
        self.versao = TagDecimal(
            nome='retEventoMDFe', tamanho=[1, 4, 1], decimais=[0, 2, 2], propriedade='versao',
            raiz='/', namespace=NAMESPACE_MDFE, valor='3.00')
        self.infEvento = InfEvento()
        self.caminho_esquema = os.path.join(DIRNAME, 'schema/', ESQUEMA_ATUAL + '/')
        self.arquivo_esquema = 'retEventoMDFe_v3.00.xsd'

    @property
    def xml(self):
        xml = '%s<retEventoMDFe xmlns="%s" versao="%s">' % (ABERTURA, NAMESPACE_MDFE, self.versao.valor)
        xml += self.infEvento.xml
        xml += '</retEventoMDFe>'
        return xml

    @xml.setter
    def xml(self, arquivo):
        if self._le_xml(arquivo):
            self.versao.xml = arquivo
            self.infEvento.xml = arquivo

# vim:expandtab:smartindent:tabstop=4:softtabstop=4:shiftwidth=4:
