# -*- coding: utf-8 -*-


from pynfe.xml_sped.base import *
import os

DIRNAME = os.path.dirname(__file__)


class NFSeCabecMsg(XMLNFSe):
    def __init__(self):
        super(NFSeCabecMsg, self).__init__()
        self.webservice = ''

    @property
    def xml(self):
        xml = XMLNFSe.get_xml(self)
        xml += '<nfeCabecMsg xmlns="http://www.portalfiscal.inf.br/nfe/wsdl/' + self.webservice + '">'
        xml += '</nfeCabecMsg>'
        return xml

    @xml.setter
    def xml(self, arquivo):
        if self._le_xml(arquivo):
            self.cUF.xml = arquivo
            self.versaoDados.xml = arquivo



class NFSeDadosMsg(XMLNFSe):
    def __init__(self):
        super(NFSeDadosMsg, self).__init__()
        self.webservice = ''
        self.dados = None
    
    @property
    def xml(self):
        xml = XMLNFSe.get_xml(self)
        xml += self.dados.raw_xml()
        return xml

    @xml.setter
    def xml(self, arquivo):
        pass



class SOAPEnvio(XMLNFSe):
    def __init__(self):
        super(SOAPEnvio, self).__init__()
        self.webservice = ''
        self.metodo = ''
        self.envio = None
        self.nfseCabecMsg = NFSeCabecMsg()
        self.nfseDadosMsg = NFSeDadosMsg()
        self._header = {'content-type': 'application/soap+xml; charset=utf-8'}

    @property
    def xml(self):
        self.nfseCabecMsg.webservice = self.webservice
        self.nfseDadosMsg.dados = self.envio
        
        self._header['content-type'] = 'application/soap+xml; charset=utf-8; action="http://homologacaosetelagoas.portalfacil.com.br/nfseserv/webservice/servicos#' + self.webservice + '"'
        
        xml = XMLNFSe.get_xml(self)
        xml += ABERTURA
        xml += '<soap:Envelope xmlns:soap="http://schemas.xmlsoap.org/wsdl/soap/">'
        xml +=     '<soap:Header>'
        xml +=             self.nfseCabecMsg.xml
        xml +=     '</soap:Header>'
        xml +=     '<soap:Body>'
        xml +=             self.nfseDadosMsg.xml
        xml +=     '</soap:Body>'
        xml += '</soap:Envelope>'
        return xml

    def set_xml(self):
        pass

    
    def get_header(self):
        header = self._header
        return header
        
    header = property(get_header)


class SOAPRetorno(XMLNFSe):
    def __init__(self):
        super(SOAPRetorno, self).__init__()
        self.webservice = ''
        self.metodo = ''
        self.nfseCabecMsg = NFSeCabecMsg()
        self.resposta = None
    
    @property
    def xml(self):
        xml = XMLNFSe.get_xml(self)
        xml += ABERTURA
        xml += '<soap:Envelope xmlns:soap="http://schemas.xmlsoap.org/wsdl/soap/">'
        # xml +=     '<soap:Header>'
        # xml +=         '<nfeCabecMsg xmlns="http://www.portalfiscal.inf.br/nfe/wsdl/' + self.webservice + '">'
        # xml +=             self.nfseCabecMsg.xml
        # xml +=         '</nfeCabecMsg>'
        # xml +=     '</soap:Header>'
        xml +=     '<soap:Body>'
        xml +=         '<' + self.metodo + 'Result xmlns="http://www.portalfiscal.inf.br/nfe/wsdl/' + self.webservice + '">'
        xml +=             self.resposta.xml
        xml +=         '</' + self.metodo + 'Result>'
        xml +=     '</soap:Body>'
        xml += '</soap:Envelope>'
        return xml
        
    @xml.setter
    def xml(self, arquivo):
        if self._le_xml(arquivo):
            self.nfseCabecMsg.xml = arquivo
            self.resposta.xml = arquivo
        
